@@ -36,24 +36,19 @@ options:
    admin_state_up:
      description:
         - Desired admin state of the created or existing router.
-     required: false
-     default: true
+     type: bool
+     default: 'yes'
    enable_snat:
      description:
         - Enable Source NAT (SNAT) attribute.
-     required: false
-     default: true
+     type: bool
    network:
      description:
         - Unique name or ID of the external gateway network.
         - required I(interfaces) or I(enable_snat) are provided.
-     required: false
-     default: None
    project:
      description:
         - Unique name or ID of the project.
-     required: false
-     default: None
      version_added: "2.2"
    external_fixed_ips:
      description:
@@ -61,8 +56,6 @@ options:
           is a dictionary with the subnet name or ID (subnet) and the IP
           address to assign on the subnet (ip). If no IP is specified,
           one is automatically assigned from that subnet.
-     required: false
-     default: None
    interfaces:
      description:
         - List of subnets to attach to the router internal interface. Default
@@ -75,14 +68,10 @@ options:
           User defined portip is often required when a multiple router need
           to be connected to a single subnet for which the default gateway has
           been already used.
-
-     required: false
-     default: None
    availability_zone:
      description:
        - Ignored. Present for backwards compatibility
-     required: false
-requirements: ["shade"]
+requirements: ["openstacksdk"]
 '''
 
 EXAMPLES = '''
@@ -180,27 +169,27 @@ router:
     contains:
         id:
             description: Router ID.
-            type: string
+            type: str
             sample: "474acfe5-be34-494c-b339-50f06aa143e4"
         name:
             description: Router name.
-            type: string
+            type: str
             sample: "router1"
         admin_state_up:
             description: Administrative state of the router.
-            type: boolean
+            type: bool
             sample: true
         status:
             description: The router status.
-            type: string
+            type: str
             sample: "ACTIVE"
         tenant_id:
             description: The tenant ID.
-            type: string
+            type: str
             sample: "861174b82b43463c9edc5202aadc60ef"
         external_gateway_info:
             description: The external gateway parameters.
-            type: dictionary
+            type: dict
             sample: {
                       "enable_snat": true,
                       "external_fixed_ips": [
@@ -232,14 +221,16 @@ def _router_internal_interfaces(cloud, router):
             yield port
 
 
-def _needs_update(cloud, module, router, network, internal_subnet_ids, internal_port_ids):
+def _needs_update(cloud, module, router, network, internal_subnet_ids, internal_port_ids, filters=None):
     """Decide if the given router needs an update.
     """
     if router['admin_state_up'] != module.params['admin_state_up']:
         return True
     if router['external_gateway_info']:
-        if router['external_gateway_info'].get('enable_snat', True) != module.params['enable_snat']:
-            return True
+        # check if enable_snat is set in module params
+        if module.params['enable_snat'] is not None:
+            if router['external_gateway_info'].get('enable_snat', True) != module.params['enable_snat']:
+                return True
     if network:
         if not router['external_gateway_info']:
             return True
@@ -249,7 +240,7 @@ def _needs_update(cloud, module, router, network, internal_subnet_ids, internal_
     # check external interfaces
     if module.params['external_fixed_ips']:
         for new_iface in module.params['external_fixed_ips']:
-            subnet = cloud.get_subnet(new_iface['subnet'])
+            subnet = cloud.get_subnet(new_iface['subnet'], filters)
             exists = False
 
             # compare the requested interface with existing, looking for an existing match
@@ -292,7 +283,7 @@ def _needs_update(cloud, module, router, network, internal_subnet_ids, internal_
     return False
 
 
-def _system_state_change(cloud, module, router, network, internal_ids, internal_portids):
+def _system_state_change(cloud, module, router, network, internal_ids, internal_portids, filters=None):
     """Check if the system state would be changed."""
     state = module.params['state']
     if state == 'absent' and router:
@@ -300,7 +291,7 @@ def _system_state_change(cloud, module, router, network, internal_ids, internal_
     if state == 'present':
         if not router:
             return True
-        return _needs_update(cloud, module, router, network, internal_ids, internal_portids)
+        return _needs_update(cloud, module, router, network, internal_ids, internal_portids, filters)
     return False
 
 
@@ -317,7 +308,8 @@ def _build_kwargs(cloud, module, router, network):
     if network:
         kwargs['ext_gateway_net_id'] = network['id']
         # can't send enable_snat unless we have a network
-        kwargs['enable_snat'] = module.params['enable_snat']
+        if module.params.get('enable_snat') is not None:
+            kwargs['enable_snat'] = module.params['enable_snat']
 
     if module.params['external_fixed_ips']:
         kwargs['ext_fixed_ips'] = []
@@ -331,7 +323,7 @@ def _build_kwargs(cloud, module, router, network):
     return kwargs
 
 
-def _validate_subnets(module, cloud):
+def _validate_subnets(module, cloud, filters=None):
     external_subnet_ids = []
     internal_subnet_ids = []
     internal_port_ids = []
@@ -347,12 +339,12 @@ def _validate_subnets(module, cloud):
     if module.params['interfaces']:
         for iface in module.params['interfaces']:
             if isinstance(iface, str):
-                subnet = cloud.get_subnet(iface)
+                subnet = cloud.get_subnet(iface, filters)
                 if not subnet:
                     module.fail_json(msg='subnet %s not found' % iface)
                 internal_subnet_ids.append(subnet['id'])
             elif isinstance(iface, dict):
-                subnet = cloud.get_subnet(iface['subnet'])
+                subnet = cloud.get_subnet(iface['subnet'], filters)
                 if not subnet:
                     module.fail_json(msg='subnet %s not found' % iface['subnet'])
                 net = cloud.get_network(iface['net'])
@@ -381,7 +373,7 @@ def main():
         state=dict(default='present', choices=['absent', 'present']),
         name=dict(required=True),
         admin_state_up=dict(type='bool', default=True),
-        enable_snat=dict(type='bool', default=True),
+        enable_snat=dict(type='bool'),
         network=dict(default=None),
         interfaces=dict(type='list', default=None),
         external_fixed_ips=dict(type='list', default=None),
@@ -393,11 +385,6 @@ def main():
                            supports_check_mode=True,
                            **module_kwargs)
 
-    if module.params['project']:
-        min_version = '1.10.0'
-    else:
-        min_version = None
-
     state = module.params['state']
     name = module.params['name']
     network = module.params['network']
@@ -406,7 +393,7 @@ def main():
     if module.params['external_fixed_ips'] and not network:
         module.fail_json(msg='network is required when supplying external_fixed_ips')
 
-    shade, cloud = openstack_cloud_from_module(module, min_version=min_version)
+    sdk, cloud = openstack_cloud_from_module(module)
     try:
         if project is not None:
             proj = cloud.get_project(project)
@@ -427,10 +414,10 @@ def main():
 
         # Validate and cache the subnet IDs so we can avoid duplicate checks
         # and expensive API calls.
-        external_ids, subnet_internal_ids, internal_portids = _validate_subnets(module, cloud)
+        external_ids, subnet_internal_ids, internal_portids = _validate_subnets(module, cloud, filters)
         if module.check_mode:
             module.exit_json(
-                changed=_system_state_change(cloud, module, router, net, subnet_internal_ids, internal_portids)
+                changed=_system_state_change(cloud, module, router, net, subnet_internal_ids, internal_portids, filters)
             )
 
         if state == 'present':
@@ -449,7 +436,7 @@ def main():
                     cloud.add_router_interface(router, port_id=int_p_id)
                 changed = True
             else:
-                if _needs_update(cloud, module, router, net, subnet_internal_ids, internal_portids):
+                if _needs_update(cloud, module, router, net, subnet_internal_ids, internal_portids, filters):
                     kwargs = _build_kwargs(cloud, module, router, net)
                     updated_router = cloud.update_router(**kwargs)
 
@@ -466,7 +453,7 @@ def main():
                         for port in ports:
                             cloud.remove_router_interface(router, port_id=port['id'])
                     if internal_portids:
-                        external_ids, subnet_internal_ids, internal_portids = _validate_subnets(module, cloud)
+                        external_ids, subnet_internal_ids, internal_portids = _validate_subnets(module, cloud, filters)
                         for int_p_id in internal_portids:
                             cloud.add_router_interface(router, port_id=int_p_id)
                         changed = True
@@ -492,7 +479,7 @@ def main():
                 cloud.delete_router(router_id)
                 module.exit_json(changed=True)
 
-    except shade.OpenStackCloudException as e:
+    except sdk.exceptions.OpenStackCloudException as e:
         module.fail_json(msg=str(e))
 
 
