@@ -29,49 +29,39 @@ options:
         description:
             - The LogicMonitor object you wish to manage.
         required: true
-        default: null
         choices: ['host', 'hostgroup']
     company:
         description:
             - The LogicMonitor account company name. If you would log in to your account at "superheroes.logicmonitor.com" you would use "superheroes".
         required: true
-        default: null
     user:
         description:
             - A LogicMonitor user name. The module will authenticate and perform actions on behalf of this user.
         required: true
-        default: null
     password:
         description:
             - The password for the chosen LogicMonitor User.
             - If an md5 hash is used, the digest flag must be set to true.
         required: true
-        default: null
     collector:
         description:
             - The fully qualified domain name of a collector in your LogicMonitor account.
             - This is optional for querying a LogicMonitor host when a displayname is specified.
             - This is required for querying a LogicMonitor host when a displayname is not specified.
-        required: false
-        default: null
     hostname:
         description:
             - The hostname of a host in your LogicMonitor account, or the desired hostname of a device to add into monitoring.
             - Required for managing hosts (target=host).
-        required: false
         default: 'hostname -f'
     displayname:
         description:
             - The display name of a host in your LogicMonitor account or the desired display name of a device to add into monitoring.
-        required: false
         default: 'hostname -f'
     fullpath:
         description:
             - The fullpath of the hostgroup object you would like to manage.
             - Recommend running on a single ansible host.
             - Required for management of LogicMonitor host groups (target=hostgroup).
-        required: false
-        default: null
 ...
 '''
 
@@ -123,30 +113,10 @@ RETURN = '''
 ...
 '''
 
+import json
 import socket
 import types
 
-HAS_LIB_JSON = True
-try:
-    import json
-    # Detect the python-json library which is incompatible
-    # Look for simplejson if that's the case
-    try:
-        if (
-            not isinstance(json.loads, types.FunctionType) or
-            not isinstance(json.dumps, types.FunctionType)
-        ):
-            raise ImportError
-    except AttributeError:
-        raise ImportError
-except ImportError:
-    try:
-        import simplejson as json
-    except ImportError:
-        HAS_LIB_JSON = False
-    except SyntaxError:
-        HAS_LIB_JSON = False
-
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.six.moves.urllib.parse import urlencode
 from ansible.module_utils._text import to_native
@@ -215,7 +185,7 @@ class LogicMonitor(object):
         resp = self.rpc("getAgents", {})
         resp_json = json.loads(resp)
 
-        if resp_json["status"] is 200:
+        if resp_json["status"] == 200:
             self.module.debug("RPC call succeeded")
             return resp_json["data"]
         else:
@@ -399,7 +369,7 @@ class LogicMonitor(object):
 class Host(LogicMonitor):
 
     def __init__(self, params, module=None):
-        """Initializor for the LogicMonitor host object"""
+        """Initializer for the LogicMonitor host object"""
         self.change = False
         self.params = params
         self.collector = None
@@ -499,7 +469,7 @@ class Host(LogicMonitor):
 class Hostgroup(LogicMonitor):
 
     def __init__(self, params, module=None):
-        """Initializor for the LogicMonitor host object"""
+        """Initializer for the LogicMonitor host object"""
         self.change = False
         self.params = params
 
@@ -579,7 +549,7 @@ def main():
             user=dict(required=True, default=None),
             password=dict(required=True, default=None, no_log=True),
 
-            collector=dict(require=False, default=None),
+            collector=dict(required=False, default=None),
             hostname=dict(required=False, default=None),
             displayname=dict(required=False, default=None),
             fullpath=dict(required=False, default=None)
@@ -587,9 +557,6 @@ def main():
         supports_check_mode=True
     )
 
-    if HAS_LIB_JSON is not True:
-        module.fail_json(msg="Unable to load JSON library")
-
     selector(module)
 
 
