@@ -288,9 +288,6 @@ class PathMapper:
         :type path: str
         :rtype: list[str]
         """
-        if path == 'lib/ansible/module_utils/__init__.py':
-            return []
-
         if not self.python_module_utils_imports:
             display.info('Analyzing python module_utils imports...')
             before = time.time()
@@ -380,6 +377,16 @@ class PathMapper:
 
         minimal = {}
 
+        if os.path.sep not in path:
+            if filename in (
+                    'azure-pipelines.yml',
+                    'shippable.yml',
+            ):
+                return all_tests(self.args)  # test infrastructure, run all tests
+
+        if is_subdir(path, '.azure-pipelines'):
+            return all_tests(self.args)  # test infrastructure, run all tests
+
         if is_subdir(path, '.github'):
             return minimal
 
@@ -514,15 +521,16 @@ class PathMapper:
                     }
 
         if is_subdir(path, data_context().content.plugin_paths['connection']):
+            units_dir = os.path.join(data_context().content.unit_path, 'plugins', 'connection')
             if name == '__init__':
                 return {
                     'integration': self.integration_all_target,
                     'windows-integration': self.integration_all_target,
                     'network-integration': self.integration_all_target,
-                    'units': 'test/units/plugins/connection/',
+                    'units': units_dir,
                 }
 
-            units_path = 'test/units/plugins/connection/test_%s.py' % name
+            units_path = os.path.join(units_dir, 'test_%s.py' % name)
 
             if units_path not in self.units_paths:
                 units_path = None
@@ -598,7 +606,8 @@ class PathMapper:
                 posix_integration_fallback = None
 
             target = self.integration_targets_by_name.get('inventory_%s' % name)
-            units_path = 'test/units/plugins/inventory/test_%s.py' % name
+            units_dir = os.path.join(data_context().content.unit_path, 'plugins', 'inventory')
+            units_path = os.path.join(units_dir, 'test_%s.py' % name)
 
             if units_path not in self.units_paths:
                 units_path = None
@@ -644,6 +653,9 @@ class PathMapper:
         if result is not None:
             return result
 
+        filename = os.path.basename(path)
+        dummy, ext = os.path.splitext(filename)
+
         minimal = {}
 
         if path.startswith('changelogs/'):
@@ -652,6 +664,24 @@ class PathMapper:
         if path.startswith('docs/'):
             return minimal
 
+        if '/' not in path:
+            if path in (
+                    '.gitignore',
+                    'COPYING',
+                    'LICENSE',
+                    'Makefile',
+            ):
+                return minimal
+
+            if ext in (
+                    '.in',
+                    '.md',
+                    '.rst',
+                    '.toml',
+                    '.txt',
+            ):
+                return minimal
+
         return None
 
     def _classify_ansible(self, path):  # type: (str) -> t.Optional[t.Dict[str, str]]
@@ -866,7 +896,6 @@ class PathMapper:
 
             if path in (
                     'setup.py',
-                    'shippable.yml',
             ):
                 return all_tests(self.args)  # broad impact, run all tests
 
